@@ -14,8 +14,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """Test FilterProcessor"""
-
-from cStringIO import StringIO
+from io import BytesIO
 
 from unittest import TestCase
 
@@ -30,7 +29,7 @@ from fastimport.processors import (
 
 # A sample input stream containing all (top level) import commands
 _SAMPLE_ALL = \
-"""blob
+b"""blob
 mark :1
 data 4
 foo
@@ -58,7 +57,7 @@ release v0.1
 #  doc/README.txt
 #  doc/index.txt
 _SAMPLE_WITH_DIR = \
-"""blob
+b"""blob
 mark :1
 data 9
 Welcome!
@@ -104,16 +103,16 @@ M 644 :4 doc/index.txt
 
 class TestCaseWithFiltering(TestCase):
 
-    def assertFiltering(self, input, params, expected):
-        outf = StringIO()
+    def assertFiltering(self, input_stream, params, expected):
+        outf = BytesIO()
         proc = filter_processor.FilterProcessor(
             params=params)
         proc.outf = outf
-        s = StringIO(input)
+        s = BytesIO(input_stream)
         p = parser.ImportParser(s)
         proc.process(p.iter_commands)
         out = outf.getvalue()
-        self.assertEquals(expected, out)
+        self.assertEqual(expected, out)
 
 class TestNoFiltering(TestCaseWithFiltering):
 
@@ -121,7 +120,7 @@ class TestNoFiltering(TestCaseWithFiltering):
         self.assertFiltering(_SAMPLE_ALL, None, _SAMPLE_ALL)
 
     def test_params_are_none(self):
-        params = {'include_paths': None, 'exclude_paths': None}
+        params = {b'include_paths': None, b'exclude_paths': None}
         self.assertFiltering(_SAMPLE_ALL, params, _SAMPLE_ALL)
 
 
@@ -131,9 +130,9 @@ class TestIncludePaths(TestCaseWithFiltering):
         # Things to note:
         # * only referenced blobs are retained
         # * from clause is dropped from the first command
-        params = {'include_paths': ['NEWS']}
+        params = {b'include_paths': [b'NEWS']}
         self.assertFiltering(_SAMPLE_WITH_DIR, params, \
-"""blob
+b"""blob
 mark :2
 data 17
 Life
@@ -152,9 +151,9 @@ M 644 :2 NEWS
         #  Additional things to note:
         # * new root: path is now index.txt, not doc/index.txt
         # * other files changed in matching commits are excluded
-        params = {'include_paths': ['doc/index.txt']}
+        params = {b'include_paths': [b'doc/index.txt']}
         self.assertFiltering(_SAMPLE_WITH_DIR, params, \
-"""blob
+b"""blob
 mark :4
 data 11
 == Docs ==
@@ -170,9 +169,9 @@ M 644 :4 index.txt
     def test_file_with_changes(self):
         #  Additional things to note:
         # * from updated to reference parents in the output
-        params = {'include_paths': ['doc/README.txt']}
+        params = {b'include_paths': [b'doc/README.txt']}
         self.assertFiltering(_SAMPLE_WITH_DIR, params, \
-"""blob
+b"""blob
 mark :1
 data 9
 Welcome!
@@ -198,9 +197,9 @@ M 644 :3 README.txt
 """)
 
     def test_subdir(self):
-        params = {'include_paths': ['doc/']}
+        params = {b'include_paths': [b'doc/']}
         self.assertFiltering(_SAMPLE_WITH_DIR, params, \
-"""blob
+b"""blob
 mark :1
 data 9
 Welcome!
@@ -232,9 +231,9 @@ M 644 :4 index.txt
 
     def test_multiple_files_in_subdir(self):
         # The new root should be the subdrectory
-        params = {'include_paths': ['doc/README.txt', 'doc/index.txt']}
+        params = {b'include_paths': [b'doc/README.txt', b'doc/index.txt']}
         self.assertFiltering(_SAMPLE_WITH_DIR, params, \
-"""blob
+b"""blob
 mark :1
 data 9
 Welcome!
@@ -268,9 +267,9 @@ M 644 :4 index.txt
 class TestExcludePaths(TestCaseWithFiltering):
 
     def test_file_in_root(self):
-        params = {'exclude_paths': ['NEWS']}
+        params = {b'exclude_paths': [b'NEWS']}
         self.assertFiltering(_SAMPLE_WITH_DIR, params, \
-"""blob
+b"""blob
 mark :1
 data 9
 Welcome!
@@ -301,9 +300,9 @@ M 644 :4 doc/index.txt
 """)
 
     def test_file_in_subdir(self):
-        params = {'exclude_paths': ['doc/README.txt']}
+        params = {b'exclude_paths': [b'doc/README.txt']}
         self.assertFiltering(_SAMPLE_WITH_DIR, params, \
-"""blob
+b"""blob
 mark :2
 data 17
 Life
@@ -331,9 +330,9 @@ M 644 :4 doc/index.txt
 """)
 
     def test_subdir(self):
-        params = {'exclude_paths': ['doc/']}
+        params = {b'exclude_paths': [b'doc/']}
         self.assertFiltering(_SAMPLE_WITH_DIR, params, \
-"""blob
+b"""blob
 mark :2
 data 17
 Life
@@ -349,9 +348,9 @@ M 644 :2 NEWS
 """)
 
     def test_multple_files(self):
-        params = {'exclude_paths': ['doc/index.txt', 'NEWS']}
+        params = {b'exclude_paths': [b'doc/index.txt', b'NEWS']}
         self.assertFiltering(_SAMPLE_WITH_DIR, params, \
-"""blob
+b"""blob
 mark :1
 data 9
 Welcome!
@@ -380,9 +379,9 @@ M 644 :3 doc/README.txt
 class TestIncludeAndExcludePaths(TestCaseWithFiltering):
 
     def test_included_dir_and_excluded_file(self):
-        params = {'include_paths': ['doc/'], 'exclude_paths': ['doc/index.txt']}
+        params = {b'include_paths': [b'doc/'], b'exclude_paths': [b'doc/index.txt']}
         self.assertFiltering(_SAMPLE_WITH_DIR, params, \
-"""blob
+b"""blob
 mark :1
 data 9
 Welcome!
@@ -416,7 +415,7 @@ M 644 :3 README.txt
 #
 # It then renames doc/README.txt => doc/README
 _SAMPLE_WITH_RENAME_INSIDE = _SAMPLE_WITH_DIR + \
-"""commit refs/heads/master
+b"""commit refs/heads/master
 mark :103
 committer d <b@c> 1234798653 +0000
 data 10
@@ -433,7 +432,7 @@ R doc/README.txt doc/README
 #
 # It then renames doc/README.txt => README
 _SAMPLE_WITH_RENAME_TO_OUTSIDE = _SAMPLE_WITH_DIR + \
-"""commit refs/heads/master
+b"""commit refs/heads/master
 mark :103
 committer d <b@c> 1234798653 +0000
 data 10
@@ -450,7 +449,7 @@ R doc/README.txt README
 #
 # It then renames NEWS => doc/NEWS
 _SAMPLE_WITH_RENAME_TO_INSIDE = _SAMPLE_WITH_DIR + \
-"""commit refs/heads/master
+b"""commit refs/heads/master
 mark :103
 committer d <b@c> 1234798653 +0000
 data 10
@@ -463,9 +462,9 @@ class TestIncludePathsWithRenames(TestCaseWithFiltering):
 
     def test_rename_all_inside(self):
         # These rename commands ought to be kept but adjusted for the new root
-        params = {'include_paths': ['doc/']}
+        params = {b'include_paths': [b'doc/']}
         self.assertFiltering(_SAMPLE_WITH_RENAME_INSIDE, params, \
-"""blob
+b"""blob
 mark :1
 data 9
 Welcome!
@@ -504,9 +503,9 @@ R README.txt README
 
     def test_rename_to_outside(self):
         # These rename commands become deletes
-        params = {'include_paths': ['doc/']}
+        params = {b'include_paths': [b'doc/']}
         self.assertFiltering(_SAMPLE_WITH_RENAME_TO_OUTSIDE, params, \
-"""blob
+b"""blob
 mark :1
 data 9
 Welcome!
@@ -545,9 +544,9 @@ D README.txt
 
     def test_rename_to_inside(self):
         # This ought to create a new file but doesn't yet
-        params = {'include_paths': ['doc/']}
+        params = {b'include_paths': [b'doc/']}
         self.assertFiltering(_SAMPLE_WITH_RENAME_TO_INSIDE, params, \
-"""blob
+b"""blob
 mark :1
 data 9
 Welcome!
@@ -586,7 +585,7 @@ M 644 :4 index.txt
 #
 # It then copies doc/README.txt => doc/README
 _SAMPLE_WITH_COPY_INSIDE = _SAMPLE_WITH_DIR + \
-"""commit refs/heads/master
+b"""commit refs/heads/master
 mark :103
 committer d <b@c> 1234798653 +0000
 data 10
@@ -603,7 +602,7 @@ C doc/README.txt doc/README
 #
 # It then copies doc/README.txt => README
 _SAMPLE_WITH_COPY_TO_OUTSIDE = _SAMPLE_WITH_DIR + \
-"""commit refs/heads/master
+b"""commit refs/heads/master
 mark :103
 committer d <b@c> 1234798653 +0000
 data 10
@@ -620,7 +619,7 @@ C doc/README.txt README
 #
 # It then copies NEWS => doc/NEWS
 _SAMPLE_WITH_COPY_TO_INSIDE = _SAMPLE_WITH_DIR + \
-"""commit refs/heads/master
+b"""commit refs/heads/master
 mark :103
 committer d <b@c> 1234798653 +0000
 data 10
@@ -634,9 +633,9 @@ class TestIncludePathsWithCopies(TestCaseWithFiltering):
 
     def test_copy_all_inside(self):
         # These copy commands ought to be kept but adjusted for the new root
-        params = {'include_paths': ['doc/']}
+        params = {b'include_paths': [b'doc/']}
         self.assertFiltering(_SAMPLE_WITH_COPY_INSIDE, params, \
-"""blob
+b"""blob
 mark :1
 data 9
 Welcome!
@@ -675,9 +674,9 @@ C README.txt README
 
     def test_copy_to_outside(self):
         # This can be ignored
-        params = {'include_paths': ['doc/']}
+        params = {b'include_paths': [b'doc/']}
         self.assertFiltering(_SAMPLE_WITH_COPY_TO_OUTSIDE, params, \
-"""blob
+b"""blob
 mark :1
 data 9
 Welcome!
@@ -709,9 +708,9 @@ M 644 :4 index.txt
 
     def test_copy_to_inside(self):
         # This ought to create a new file but doesn't yet
-        params = {'include_paths': ['doc/']}
+        params = {b'include_paths': [b'doc/']}
         self.assertFiltering(_SAMPLE_WITH_COPY_TO_INSIDE, params, \
-"""blob
+b"""blob
 mark :1
 data 9
 Welcome!
@@ -748,7 +747,7 @@ M 644 :4 index.txt
 #  doc/README.txt
 #  doc/index.txt
 _SAMPLE_WITH_DELETEALL = \
-"""blob
+b"""blob
 mark :1
 data 9
 Welcome!
@@ -784,9 +783,9 @@ M 644 :4 doc/index.txt
 class TestIncludePathsWithDeleteAll(TestCaseWithFiltering):
 
     def test_deleteall(self):
-        params = {'include_paths': ['doc/index.txt']}
+        params = {b'include_paths': [b'doc/index.txt']}
         self.assertFiltering(_SAMPLE_WITH_DELETEALL, params, \
-"""blob
+b"""blob
 mark :4
 data 11
 == Docs ==
@@ -803,7 +802,7 @@ M 644 :4 index.txt
 
 
 _SAMPLE_WITH_TAGS = _SAMPLE_WITH_DIR + \
-"""tag v0.1
+b"""tag v0.1
 from :100
 tagger d <b@c> 1234798653 +0000
 data 12
@@ -821,9 +820,9 @@ class TestIncludePathsWithTags(TestCaseWithFiltering):
         # If a tag references a commit with a parent we kept,
         # keep the tag but adjust 'from' accordingly.
         # Otherwise, delete the tag command.
-        params = {'include_paths': ['NEWS']}
+        params = {b'include_paths': [b'NEWS']}
         self.assertFiltering(_SAMPLE_WITH_TAGS, params, \
-"""blob
+b"""blob
 mark :2
 data 17
 Life
@@ -845,7 +844,7 @@ release v0.2
 
 
 _SAMPLE_WITH_RESETS = _SAMPLE_WITH_DIR + \
-"""reset refs/heads/foo
+b"""reset refs/heads/foo
 reset refs/heads/bar
 from :102
 """
@@ -856,9 +855,9 @@ class TestIncludePathsWithResets(TestCaseWithFiltering):
         # Resets init'ing a branch (without a from) are passed through.
         # If a reset references a commit with a parent we kept,
         # keep the reset but adjust 'from' accordingly.
-        params = {'include_paths': ['NEWS']}
+        params = {b'include_paths': [b'NEWS']}
         self.assertFiltering(_SAMPLE_WITH_RESETS, params, \
-"""blob
+b"""blob
 mark :2
 data 17
 Life
@@ -879,7 +878,7 @@ from :101
 
 # A sample input stream containing empty commit
 _SAMPLE_EMPTY_COMMIT = \
-"""blob
+b"""blob
 mark :1
 data 4
 foo
@@ -898,7 +897,7 @@ empty commit
 
 # A sample input stream containing unresolved from and merge references
 _SAMPLE_FROM_MERGE_COMMIT = \
-"""blob
+b"""blob
 mark :1
 data 4
 foo
@@ -935,11 +934,11 @@ M 644 :99 data/DATA2
 """
 
 class TestSquashEmptyCommitsFlag(TestCaseWithFiltering):
-    
+
     def test_squash_empty_commit(self):
-        params = {'include_paths': None, 'exclude_paths': None}
+        params = {b'include_paths': None, b'exclude_paths': None}
         self.assertFiltering(_SAMPLE_EMPTY_COMMIT, params, \
-"""blob
+b"""blob
 mark :1
 data 4
 foo
@@ -952,13 +951,13 @@ M 644 :1 COPYING
 """)
 
     def test_keep_empty_commit(self):
-        params = {'include_paths': None, 'exclude_paths': None, 'squash_empty_commits': False}
+        params = {b'include_paths': None, b'exclude_paths': None, b'squash_empty_commits': False}
         self.assertFiltering(_SAMPLE_EMPTY_COMMIT, params, _SAMPLE_EMPTY_COMMIT)
 
     def test_squash_unresolved_references(self):
-        params = {'include_paths': None, 'exclude_paths': None}
+        params = {b'include_paths': None, b'exclude_paths': None}
         self.assertFiltering(_SAMPLE_FROM_MERGE_COMMIT, params, \
-"""blob
+b"""blob
 mark :1
 data 4
 foo
@@ -995,15 +994,15 @@ M 644 :99 data/DATA2
 """)
 
     def test_keep_unresolved_from_and_merge(self):
-        params = {'include_paths': None, 'exclude_paths': None, 'squash_empty_commits': False}
+        params = {b'include_paths': None, b'exclude_paths': None, b'squash_empty_commits': False}
         self.assertFiltering(_SAMPLE_FROM_MERGE_COMMIT, params, _SAMPLE_FROM_MERGE_COMMIT)
 
     def test_with_excludes(self):
-        params = {'include_paths': None,
-                  'exclude_paths': ['data/DATA'],
-                  'squash_empty_commits': False}
+        params = {b'include_paths': None,
+                  b'exclude_paths': [b'data/DATA'],
+                  b'squash_empty_commits': False}
         self.assertFiltering(_SAMPLE_FROM_MERGE_COMMIT, params, \
-"""blob
+b"""blob
 mark :1
 data 4
 foo
@@ -1035,11 +1034,11 @@ M 644 :99 data/DATA2
 """)
 
     def test_with_file_includes(self):
-        params = {'include_paths': ['COPYING', 'data/DATA2'],
-                  'exclude_paths': None,
-                  'squash_empty_commits': False}
+        params = {b'include_paths': [b'COPYING', b'data/DATA2'],
+                  b'exclude_paths': None,
+                  b'squash_empty_commits': False}
         self.assertFiltering(_SAMPLE_FROM_MERGE_COMMIT, params, \
-"""blob
+b"""blob
 mark :1
 data 4
 foo
@@ -1070,13 +1069,13 @@ merge :1001
 M 644 :99 data/DATA2
 """
 )
-        
+
     def test_with_directory_includes(self):
-        params = {'include_paths': ['data/'],
-                  'exclude_paths': None,
-                  'squash_empty_commits': False}
+        params = {b'include_paths': [b'data/'],
+                  b'exclude_paths': None,
+                  b'squash_empty_commits': False}
         self.assertFiltering(_SAMPLE_FROM_MERGE_COMMIT, params, \
-"""commit refs/heads/master
+b"""commit refs/heads/master
 mark :3
 committer Joe <joe@example.com> 1234567890 +1000
 data 6
